(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     81982,       2700]
NotebookOptionsPosition[     65874,       2139]
NotebookOutlinePosition[     69364,       2230]
CellTagsIndexPosition[     69321,       2227]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Box Reference Structures", "Section",
 CellID->700496117],

Cell[BoxData["NotebookSelection"], "Input",
 CellID->82038956],

Cell[CellGroupData[{

Cell["BoxReference", "Subsection",
 CellID->732885565],

Cell["\<\
A box reference is a reference in a notebook to a box structure. It contains \
sufficient information to locate a given box (or selection) within a \
notebook. Each box in a notebook can contain one or many boxesID's and the \
box reference refers to these boxIDs.\
\>", "ExampleText",
 CellID->1584626314],

Cell[BoxData[GridBox[{
   {
    RowBox[{"BoxReference", "[", 
     RowBox[{
      StyleBox["nb", "TI"], ",", 
      StyleBox["id", "TI"], ",", 
      StyleBox["opts", "TI"]}], "]"}], Cell[TextData[{
     "This represents a box reference with boxID ",
     StyleBox["id", "TI"],
     ". When used with functions which match box structures against this ",
     "box reference",
     ", the box structure matches if and only if it has a boxID which \
contains ",
     StyleBox["id", "TI"],
     "."
    }], "TableText"]},
   {
    RowBox[{"BoxReference", "[", 
     RowBox[{
      StyleBox["nb", "TI"], ",", 
      RowBox[{"{", 
       RowBox[{
        StyleBox[
         SubscriptBox["id", "1"], "TI"], ",", 
        StyleBox[
         SubscriptBox["id", "2"], "TI"], ",", "\[Ellipsis]", ",", " ", 
        StyleBox[
         SubscriptBox["id", "last"], "TI"]}], "}"}], ",", 
      StyleBox["opts", "TI"]}], "]"}], Cell[TextData[{
     "This represents a box reference with boxID chain ",
     Cell[BoxData[
      RowBox[{"{", 
       RowBox[{
        StyleBox[
         SubscriptBox["id", "1"], "TI"], ",", 
        StyleBox[
         SubscriptBox["id", "2"], "TI"], ",", "\[Ellipsis]", ",", " ", 
        StyleBox[
         SubscriptBox["id", "last"], "TI"]}], "}"}]]],
     ". When used with functions which match box structures against this ",
     "box reference",
     ", the box structure matches if and only if it has a boxID which \
contains the ",
     Cell[BoxData[
      StyleBox[
       SubscriptBox["id", "last"], "TI"]]],
     ", moreover this box must have a parent which contains the boxID ",
     Cell[BoxData[
      StyleBox[
       SubscriptBox["id", 
        RowBox[{"last", "-", "1"}]], "TI"]]],
     ", and that box must have a parent which contains the previous boxID, \
etc. In this way there need exist a chain of boxes which contain the \
specified boxIDs."
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->1894808774],

Cell[CellGroupData[{

Cell["BoxReference structure options are: ", "Notes",
 CellID->828156497],

Cell[BoxData[GridBox[{
   {" ", 
    RowBox[{"FE`Segments", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        StyleBox["left", "TI"], ",", 
        StyleBox["right", "TI"]}], "}"}], "}"}]}], Cell[TextData[{
     "Specifies that a selection should be made from character count ",
     StyleBox["left", "TI"],
     " to character count ",
     StyleBox["right", "TI"],
     " relative to the box structure matched."
    }], "TableText"]},
   {" ", 
    RowBox[{"FE`SelectionHash", "\[Rule]", 
     StyleBox["hash", "TI"]}], Cell["\<\
Specifies a hash for the contents of the box structure. If the hash of the \
contents of the box structure do not match this hash then the box structure \
is deemed not to match.\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`BoxOffset", "\[Rule]", 
     StyleBox["directives", "TI"]}], Cell["\<\
Specifies a set of directives which can be used to locate a box relative to \
the matching box\
\>", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{
      GrayLevel[0.7]}}}},
 CellID->984728872]
}, Closed]],

Cell[CellGroupData[{

Cell["FE`BoxOffset directives are:", "Notes",
 CellID->1829167922],

Cell[BoxData[GridBox[{
   {" ", 
    RowBox[{"FE`BoxParent", "[", 
     StyleBox["nnn", "TI"], "]"}], Cell[TextData[{
     "The refrenced box should be offset to the ",
     StyleBox["nnn'th", "TI"],
     " parent of the matching box"
    }], "TableText"]},
   {" ", 
    RowBox[{"FE`BoxAbsoluteSibling", "[", 
     StyleBox["nnn", "TI"], "]"}], Cell[TextData[{
     "The refrenced box should be offset to the ",
     StyleBox["nnn'th", "TI"],
     " absolute sibling of the matching box"
    }], "TableText"]},
   {" ", 
    RowBox[{"FE`BoxRightSibling", "[", 
     StyleBox["nnn", "TI"], "]"}], Cell[TextData[{
     "The refrenced box should be offset to be the ",
     StyleBox["nnn'th", "TI"],
     " sibling to the right of the matching box"
    }], "TableText"]},
   {" ", 
    RowBox[{"FE`BoxLeftSibling", "[", 
     StyleBox["nnn", "TI"], "]"}], Cell[TextData[{
     "The refrenced box should be offset to be the ",
     StyleBox["nnn'th", "TI"],
     " sibling to the left of the matching box"
    }], "TableText"]},
   {" ", 
    RowBox[{"FE`BoxChild", "[", 
     RowBox[{
      StyleBox[
       SubscriptBox["n", "1"], "TI"], ",", 
      StyleBox[
       SubscriptBox["n", "2"], "TI"], ",", "\[Ellipsis]"}], "]"}], Cell[
    TextData[{
     "The refrenced box should be offset to be the child ",
     Cell[BoxData[
      StyleBox[
       SubscriptBox["n", "1"], "TI"]]],
     " of the matching box, and further child ",
     Cell[BoxData[
      SubscriptBox["n", "2"]]]
    }], "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{
      GrayLevel[0.7]}}}},
 CellID->1596858249]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellID->237833693],

Cell[BoxData[
 RowBox[{"FE`BoxReference", "[", 
  RowBox[{"nb", ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["id", "1"], ",", 
     SubscriptBox["id", "2"], ",", "\[Ellipsis]"}], "}"}], ",", "opts"}], 
  "]"}]], "Input",
 CellID->1892183385],

Cell[BoxData[
 RowBox[{"FE`BoxReference", "[", 
  RowBox[{"nb", ",", 
   RowBox[{"{", 
    RowBox[{"foo", ",", 
     RowBox[{"{", 
      RowBox[{"bar", ",", "blob"}], "}"}], ",", "linkOne"}], "}"}], ",", 
   "opts"}], "]"}]], "Input",
 CellID->1988306919],

Cell[BoxData[
 RowBox[{"FE`BoxReference", "[", 
  RowBox[{"nb", ",", 
   RowBox[{"{", 
    RowBox[{"foo", ",", "bar", ",", 
     RowBox[{"{", 
      RowBox[{"linkOne", ",", "myLink"}], "}"}]}], "}"}], ",", "opts"}], 
  "]"}]], "Input",
 CellID->481356666],

Cell[BoxData[
 RowBox[{"FE`BoxReference", "[", 
  RowBox[{"nb", ",", 
   RowBox[{"{", 
    RowBox[{"foo", ",", 
     RowBox[{"{", 
      RowBox[{"blob", ",", "bar", ",", "mmug"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"linkOne", ",", "myLink"}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellID->590587213],

Cell[BoxData[
 RowBox[{"FE`BoxReference", "[", 
  RowBox[{"nb", ",", 
   RowBox[{"{", 
    RowBox[{"Chapter1", ",", 
     RowBox[{"ChapterRef", "[", 
      RowBox[{"1", ",", "2", ",", "47"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"linkOne", ",", "myLink"}], "}"}]}], "}"}], ",", "opts"}], 
  "]"}]], "Input",
 CellID->329872457],

Cell[BoxData[
 RowBox[{"a", "+", 
  SuperscriptBox["b", 
   SqrtBox["2"]], "+", "abcde", "+", "wert"}]], "Input",
 CellID->404509676],

Cell["SubscriptBox[b,sqrt[2],boxId->foo]", "Text",
 CellID->1808381777],

Cell[BoxData[
 RowBox[{"FE`BoxReference", "[", 
  RowBox[{"nb", ",", "foo", ",", 
   RowBox[{"FE`BoxOffsets", "->", 
    RowBox[{"{", 
     RowBox[{"RightSibiling", "[", "2", "]"}], "}"}]}], ",", 
   RowBox[{"FE`Segments", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}]}]}], "]"}]], "Input",
 CellID->136470048],

Cell["\<\
The following offset specifies that after finding the box structure which \
matches the boxID chain specified in the box reference, use a box relative to \
this matching box. Ie for the example below the offset box is the second \
child of the first child of the third absolute sibling of the parent of the \
parent of the matched box. That box is the box all operations are done on eg, \
returning the contents, replacing the contents, removing, or adding box id's, \
etc.\
\>", "ExampleText",
 CellID->185165841],

Cell[BoxData[
 RowBox[{"FE`BoxOffset", "\[Rule]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"FE`Parent", "[", "2", "]"}], ",", 
    RowBox[{"FE`AbsoluteSibling", "[", "3", "]"}], ",", 
    RowBox[{"FE`Child", "[", 
     RowBox[{"1", ",", "2"}], "]"}]}], "}"}]}]], "Input",
 CellID->1016063255]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["BoxReference search options", "Subsection",
 CellID->945442950],

Cell["\<\
The various functions RemoveBoxIDs, BoxReferenceExists, BoxReferenceFind, \
BoxReferenceRead, BoxReferenceReplace, and BoxReferenceSetOptions, \
BoxReferenceGetOptions all search for box structures which match a given box \
reference. They share common options as follows.\
\>", "ExampleText",
 CellID->1535105644],

Cell[CellGroupData[{

Cell["Possible FE`SearchStart specifications are: ", "Notes",
 CellID->640650408],

Cell[BoxData[GridBox[{
   {" ", "\"\<StartFromBeginning\>\"", Cell[
    "Start the search from the begining of the notebook", "TableText"]},
   {" ", "\"\<StartFromEnd\>\"", Cell[
    "Start the search from the end of the notebook", "TableText"]},
   {" ", "\"\<StartFromCurrentSelectionBeginning\>\"", Cell["\<\
Start the search from the begining of the current selection in the notebook\
\>", "TableText"]},
   {" ", "\"\<StartFromCurrentSelectionEnd\>\"", Cell["\<\
Start the search from the end of the current selection in the notebook\
\>", "TableText"]},
   {" ", "Automatic", Cell[
    "Defaults to \"StartFromCurrentSelectionBegining\"", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{
      GrayLevel[0.7]}}}},
 CellID->2075884845]
}, Closed]],

Cell[CellGroupData[{

Cell["Possible FE`SearchStop specifications are: ", "Notes",
 CellID->2042728305],

Cell[BoxData[GridBox[{
   {" ", "\"\<StopAtEnd\>\"", Cell["\<\
When the search reaches either the begining or the end of the notebook the \
search will stop\
\>", "TableText"]},
   {" ", "\"\<LoopAround\>\"", Cell["\<\
The search will continue until the search reaches the initial start of the \
search, ie the entier notebook will be searched.\
\>", "TableText"]},
   {" ", "Automatic", Cell["Defaults to \"LoopAround\"", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{
      GrayLevel[0.7]}}}},
 CellID->313557546]
}, Closed]],

Cell[CellGroupData[{

Cell["Possible FE`SearchDirection specifications are: ", "Notes",
 CellID->1800650045],

Cell[BoxData[GridBox[{
   {" ", "Forward", Cell["Search in the Forward direction", "TableText"]},
   {" ", "Backward", Cell["Search in the Backward direction", "TableText"]},
   {" ", "Automatic", Cell["Defaults to Forward", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{
      GrayLevel[0.7]}}}},
 CellID->1185752791]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Packets dealing with BoxIDs", "Section"],

Cell[CellGroupData[{

Cell["AddBoxIDs", "Subsection"],

Cell["\<\
The packet FrontEnd`AddBoxIDs will mark a box selection with a BoxID and \
return a box reference to this marked box.\
\>", "ExampleText"],

Cell[BoxData[GridBox[{
   {
    RowBox[{"AddBoxIDs", "[", 
     StyleBox["nb", "TI"], "]"}], Cell["\<\
Mark the closest enclosing box of the current selection with a unique boxID \
of the form \"Selection$nnn\" and returns a BoxReference object which \
represents a refrence to this selection.\
\>", "TableText"]},
   {
    RowBox[{"AddBoxIDs", "[", 
     RowBox[{
      StyleBox["nb", "TI"], ",", 
      StyleBox["id", "TI"]}], "]"}], Cell[TextData[{
     "Add the given boxID ",
     StyleBox["id", "TI"],
     " to the boxIDs of the closest enclosing box of the current notebook \
selection. It will return a ",
     "BoxReference",
     " object which represents a refrence to this selection."
    }], "TableText"]},
   {
    RowBox[{"AddBoxIDs", "[", 
     RowBox[{
      StyleBox["ref", "TI"], ",", 
      StyleBox["id", "TI"], ",", 
      StyleBox["opts", "TI"]}], "]"}], Cell[TextData[{
     "Add the given boxID ",
     StyleBox["id", "TI"],
     " to the boxIDs of the box referenced from the BoxReference. Return a \
BoxReference object representing this refrence."
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->911805233],

Cell["Examples", "Subsubsection",
 CellID->661661166],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellID->1089009184],

Cell[BoxData[
 RowBox[{
  RowBox[{"nb", "=", 
   RowBox[{"CreateDocument", " ", "[", 
    RowBox[{
     RowBox[{"Cell", "[", 
      RowBox[{"CellGroupData", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cell", "[", 
           RowBox[{"\"\<Blah\>\"", ",", "\"\<Subtitle\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{"\"\<floo\>\"", ",", "\"\<Text\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{
            RowBox[{"BoxData", "[", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<f\>\"", ",", "\"\<[\>\"", ",", 
                RowBox[{"RowBox", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"SuperscriptBox", "[", 
                    RowBox[{"\"\<ab\>\"", ",", "\"\<2\>\"", ",", 
                    RowBox[{"BoxID", "\[RuleDelayed]", "\"\<foo\>\""}]}], 
                    "]"}], ",", "\"\<+\>\"", ",", "\"\<12\>\""}], "}"}], 
                 "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], "]"}], ",", 
            "\"\<Input\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{
            RowBox[{"BoxData", "[", 
             RowBox[{"PaneBox", "[", 
              RowBox[{
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"SuperscriptBox", "[", 
                   RowBox[{"\"\<xyz\>\"", ",", "\"\<q\>\"", ",", 
                    RowBox[{"BoxID", "\[RuleDelayed]", 
                    RowBox[{"{", 
                    RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}]}]}], 
                   "]"}], ",", "\"\<+\>\"", ",", "\"\<12\>\""}], "}"}], "]"}],
                ",", 
               RowBox[{"BoxID", "\[RuleDelayed]", "\"\<Pane\>\""}]}], "]"}], 
             "]"}], ",", "\"\<Input\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{
            RowBox[{"BoxData", "[", 
             RowBox[{"GridBox", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"FractionBox", "[", 
                   RowBox[{
                    RowBox[{"RowBox", "[", 
                    RowBox[{"{", 
                    RowBox[{"\"\<r\>\"", ",", "\"\<+\>\"", ",", "\"\<t\>\""}],
                     "}"}], "]"}], ",", "\"\<343\>\"", ",", 
                    RowBox[{"BoxID", "\[RuleDelayed]", "\"\<fr\>\""}]}], 
                   "]"}], ",", "\"\<e\>\""}], "}"}], "}"}], ",", 
               RowBox[{"BoxID", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"\"\<gr\>\"", ",", "\"\<blip\>\""}], "}"}]}]}], 
              "]"}], "]"}], ",", "\"\<Input\>\""}], "]"}]}], "}"}], ",", 
        "Open"}], "]"}], "]"}], ",", 
     RowBox[{"WindowSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"410", ",", "718"}], "}"}]}], ",", 
     RowBox[{"WindowMargins", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "55"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"30", ",", "Automatic"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellID->2121715754],

Cell[CellGroupData[{

Cell["Multiple BoxID Examples", "Subsubsubsection",
 CellID->710719043],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nb", " ", "=", " ", 
   RowBox[{"CreateDocument", "[", 
    RowBox[{"a", "+", 
     SuperscriptBox["b", "2"], "+", "c"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"SelectionMove", "[", 
  RowBox[{"nb", ",", "Before", ",", "CellContents"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"SelectionMove", "[", 
  RowBox[{"nb", ",", "Next", ",", "Character", ",", "2"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"SelectionMove", "[", 
  RowBox[{"nb", ",", "All", ",", "Character", ",", "2"}], "]"}]}], "Input",
 CellID->868892796],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ref", " ", "=", 
  RowBox[{"MathLink`CallFrontEnd", "@", 
   RowBox[{"FrontEnd`AddBoxIDs", "[", "nb", "]"}]}]}]], "Input",
 CellID->592422772],

Cell[BoxData[
 RowBox[{"FE`BoxReference", "[", 
  RowBox[{
   InterpretationBox[
    RowBox[{"NotebookObject", "[", 
     PanelBox[GridBox[{
        {
         TooltipBox[
          ButtonBox[
           StyleBox[
            
            DynamicBox[FEPrivate`FrontEndResource[
             "FEBitmaps", "ManipulatePasteIcon"],
             ImageSizeCache->{13., {4., 9.}}],
            DynamicUpdating->True],
           BaseStyle->{},
           ButtonFrame->None,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetSelectedNotebook[
               NotebookObject[
                FrontEndObject[
                 LinkObject["zcg_shm", 1, 1]], 20]]}],
           Evaluator->None,
           Method->"Queued"],
          DynamicBox[
           FEPrivate`FrontEndResource[
           "FEStrings", "NotebookObjectToTheFront"]]], 
         StyleBox["\<\"Untitled-2\"\>",
          StripOnInput->False,
          FontColor->GrayLevel[0.5]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}}],
      FrameMargins->{{4, 5}, {4, 4}}], "]"}],
    NotebookObject[
     FrontEndObject[
      LinkObject["zcg_shm", 1, 1]], 20],
    Editable->False], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\<\"gr\"\>", ",", "\<\"blip\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"fr\"\>", ",", 
       RowBox[{"\<\"Selection\"\>", "[", "145361107", "]"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"FE`Segments", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], "}"}]}]}], "]"}]], "Output",
 CellID->686995272]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "@", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", "ref", "]"}]}]], "Input",
 CellID->998971198],

Cell[BoxData["True"], "Output",
 CellID->1457450232]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SetBoxIDs", "Subsection",
 CellID->55799479],

Cell["\<\
The packet FrontEnd`SetBoxIDs will mark a box selection with a BoxID and \
return a box reference to this marked box.\
\>", "ExampleText",
 CellID->101363491],

Cell[BoxData[GridBox[{
   {
    RowBox[{"SetBoxIDs", "[", 
     RowBox[{
      StyleBox["nb", "TI"], ",", 
      StyleBox["id", "TI"]}], "]"}], Cell[TextData[{
     "Change the boxIDs of the closest enclosing box of the current selection \
to the given ",
     StyleBox["id", "TI"],
     " and return a ",
     "BoxReference",
     " object which represents a refrence to this selection."
    }], "TableText"]},
   {
    RowBox[{"SetBoxIDs", "[", 
     RowBox[{
      StyleBox["ref", "TI"], ",", 
      StyleBox["id", "TI"], ",", 
      StyleBox["opts", "TI"]}], "]"}], Cell[TextData[{
     "Change the boxIDs of the box referenced from the BoxReference to the \
given ",
     StyleBox["id", "TI"],
     " and return a BoxReference object representing this refrence."
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->1518973461],

Cell[CellGroupData[{

Cell["Possible options for the packet SetBoxIDs are: ", "Notes",
 CellID->122813910],

Cell[BoxData[GridBox[{
   {" ", 
    RowBox[{"FE`SearchStart", "\[Rule]", 
     StyleBox["start", "TI"]}], Cell["\<\
Specifies from what place within the notebook we start the search for a box \
which matches the given box reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchStop", "\[Rule]", 
     StyleBox["stop", "TI"]}], Cell["\<\
Specifies how we will stop the search for the box which matches the given box \
reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchDirection", "\[Rule]", 
     StyleBox["dir", "TI"]}], Cell["\<\
Specifies in which direction we will the selection be just after the end of \
the present unit \
\>", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{
      GrayLevel[0.7]}}}},
 CellID->401600603]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GetBoxIDs", "Subsection",
 CellID->1686860824],

Cell["\<\
The packet FrontEnd`GetBoxIDs will return a box reference to the current \
selection if possible. \
\>", "ExampleText",
 CellID->2138244921],

Cell[BoxData[GridBox[{
   {
    RowBox[{"GetBoxIDs", "[", 
     StyleBox["nb", "TI"], "]"}], Cell["\<\
Return a box reference to the current selection if possible. If no boxIDs \
exist on which to base a box reference return $Failed.\
\>", "TableText"]}
  }]], "DefinitionBox",
 CellID->1491038349]
}, Closed]],

Cell[CellGroupData[{

Cell["RemoveBoxIDs", "Subsection",
 CellID->894854800],

Cell["\<\
The packet FrontEnd`RemoveBoxIDs will attempt to remove any boxIDs from the \
first box structure matching the given box reference. The specified options \
control from what point we want to start searching from within the notebook, \
in which direction, and when we stop searching.\
\>", "ExampleText",
 CellID->996643659],

Cell[BoxData[GridBox[{
   {
    RowBox[{"RemoveBoxIDs", "[", 
     RowBox[{
      StyleBox["ref", "TI"], ",", 
      StyleBox["opts", "TI"]}], "]"}], Cell[TextData[{
     "Remove any boxIDs from the nearest box structure in the notebook which \
matches the ",
     "box reference",
     " ",
     StyleBox["ref", "TI"],
     ". Return True if we found a matching box structure."
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->217530213],

Cell[CellGroupData[{

Cell["Possible options for the packet RemoveBoxIDs are: ", "Notes",
 CellID->1910800934],

Cell[BoxData[GridBox[{
   {" ", 
    RowBox[{"FE`SearchStart", "\[Rule]", 
     StyleBox["start", "TI"]}], Cell["\<\
Specifies from what place within the notebook we start the search for a box \
which matches the given box reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchStop", "\[Rule]", 
     StyleBox["stop", "TI"]}], Cell["\<\
Specifies how we will stop the search for the box which matches the given box \
reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchDirection", "\[Rule]", 
     StyleBox["dir", "TI"]}], Cell["\<\
Specifies in which direction we will the selection be just after the end of \
the present unit \
\>", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{
      GrayLevel[0.7]}}}},
 CellID->1579348800]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Packets dealing with BoxReferences", "Section",
 CellID->1066281244],

Cell[CellGroupData[{

Cell["BoxReferenceExists", "Subsection",
 CellID->1115341512],

Cell["\<\
The packet FrontEnd`BoxReferenceExists will determine if a box structure \
matching the given box reference exists.\
\>", "ExampleText",
 CellID->1328217339],

Cell[BoxData[GridBox[{
   {
    RowBox[{"BoxReferenceExists", "[", 
     RowBox[{
      StyleBox["ref", "TI"], ",", 
      StyleBox["opts", "TI"]}], "]"}], Cell["\<\
Determine if a box structure matching the given box reference exists. \
\>", "TableText"]}
  }]], "DefinitionBox",
 CellID->2030364221],

Cell[CellGroupData[{

Cell["Possible options for the packet BoxReferenceFind are: ", "Notes",
 CellID->816311517],

Cell[BoxData[GridBox[{
   {" ", 
    RowBox[{"FE`SearchStart", "\[Rule]", 
     StyleBox["start", "TI"]}], Cell["\<\
Specifies from what place within the notebook we start the search for a box \
which matches the given box reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchStop", "\[Rule]", 
     StyleBox["stop", "TI"]}], Cell["\<\
Specifies how we will stop the search for the box which matches the given box \
reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchDirection", "\[Rule]", 
     StyleBox["dir", "TI"]}], Cell["\<\
Specifies in which direction we will the selection be just after the end of \
the present unit \
\>", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{
      GrayLevel[0.7]}}}},
 CellID->1622129183],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceExists", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Pane\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}]}], "}"}]}], "]"}], 
   "]"}], "]"}]], "Input",
 CellID->144232118],

Cell[BoxData[
 RowBox[{"SuperscriptBox", "[", 
  RowBox[{"\<\"xyz\"\>", ",", "\<\"q\"\>", ",", 
   RowBox[{"BoxID", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"\<\"foo\"\>", ",", "\<\"bar\"\>"}], "}"}]}]}], "]"}]], "Output",\

 CellID->2130866529]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["BoxReferenceFind", "Subsection"],

Cell["\<\
The packet FrontEnd`BoxReferenceFind will find the first box structure \
matching the given box reference and set the selection to this box structure. \
If such a box is found BoxReferenceFind will change the notebooks selection \
to be the matching box structure. The specified options control from what \
point we want to start searching from within the notebook, in which \
direction, and when we stop searching.\
\>", "ExampleText"],

Cell["\<\
The box reference can optionally specify a chain of boxIDs which requires \
that there exist box parents of the box structure which have boxIDs which \
match the boxIDs in the box id chain. Additionally, the box reference can \
optionally contain an offset to parents, siblings, or children.\
\>", "ExampleText",
 CellID->1869752951],

Cell[BoxData[GridBox[{
   {
    RowBox[{"BoxReferenceFind", "[", 
     RowBox[{
      StyleBox["ref", "TI"], ",", 
      StyleBox["opts", "TI"]}], "]"}], Cell[TextData[{
     "This will attempt to find the nearest box structure in the notebook \
which matches the ",
     "box reference",
     " ",
     StyleBox["ref", "TI"],
     ". If a matching box structure is found set the selection to that box \
and return ",
     StyleBox["True", "MR"],
     ". Return ",
     StyleBox["False", "MR"],
     " otherwise. "
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->1721909340],

Cell[CellGroupData[{

Cell["Possible options for the packet BoxReferenceFind are: ", "Notes",
 CellID->32012],

Cell[BoxData[GridBox[{
   {" ", 
    RowBox[{"FE`SearchStart", "\[Rule]", 
     StyleBox["start", "TI"]}], Cell["\<\
Specifies from what place within the notebook we start the search for a box \
which matches the given box reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchStop", "\[Rule]", 
     StyleBox["stop", "TI"]}], Cell["\<\
Specifies how we will stop the search for the box which matches the given box \
reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchDirection", "\[Rule]", 
     StyleBox["dir", "TI"]}], Cell["\<\
Specifies in which direction we will the selection be just after the end of \
the present unit \
\>", "TableText"]},
   {" ", 
    RowBox[{"\"\<AutoScroll\>\"", "\[Rule]", " ", 
     RowBox[{"True", "|", "False"}]}], Cell["\<\
Upon finding a matching box reference does the FrontEnd automatically scroll \
to the matched reference. Defaults to True.\
\>", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{
      GrayLevel[0.7]}}}},
 CellID->110873307]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellID->1784821710],

Cell[BoxData[
 RowBox[{
  RowBox[{"nb", "=", 
   RowBox[{"CreateDocument", " ", "[", 
    RowBox[{
     RowBox[{"Cell", "[", 
      RowBox[{"CellGroupData", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cell", "[", 
           RowBox[{"\"\<Blah\>\"", ",", "\"\<Subtitle\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{"\"\<floo\>\"", ",", "\"\<Text\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{
            RowBox[{"BoxData", "[", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<f\>\"", ",", "\"\<[\>\"", ",", 
                RowBox[{"RowBox", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"SuperscriptBox", "[", 
                    RowBox[{"\"\<ab\>\"", ",", "\"\<2\>\"", ",", 
                    RowBox[{"BoxID", "\[RuleDelayed]", "\"\<foo\>\""}]}], 
                    "]"}], ",", "\"\<+\>\"", ",", "\"\<12\>\""}], "}"}], 
                 "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], "]"}], ",", 
            "\"\<Input\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{
            RowBox[{"BoxData", "[", 
             RowBox[{"PaneBox", "[", 
              RowBox[{
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"SuperscriptBox", "[", 
                   RowBox[{"\"\<xyz\>\"", ",", "\"\<q\>\"", ",", 
                    RowBox[{"BoxID", "\[RuleDelayed]", 
                    RowBox[{"{", 
                    RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}]}]}], 
                   "]"}], ",", "\"\<+\>\"", ",", "\"\<12\>\""}], "}"}], "]"}],
                ",", 
               RowBox[{"BoxID", "\[RuleDelayed]", "\"\<Pane\>\""}]}], "]"}], 
             "]"}], ",", "\"\<Input\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{
            RowBox[{"BoxData", "[", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<r\>\"", ",", "\"\<+\>\"", ",", "\"\<t\>\""}], 
               "}"}], "]"}], "]"}], ",", "\"\<Input\>\""}], "]"}]}], "}"}], 
        ",", "Open"}], "]"}], "]"}], ",", 
     RowBox[{"WindowSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"410", ",", "718"}], "}"}]}], ",", 
     RowBox[{"WindowMargins", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "55"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"30", ",", "Automatic"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellID->1672851568],

Cell[CellGroupData[{

Cell["Multiple BoxID Examples", "Subsubsubsection",
 CellID->296387369],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<Pane\>\"", ",", "\"\<bar\>\""}], "}"}]}], "]"}], ",", " ",
     
    RowBox[{"AutoScroll", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
 CellID->2068678937],

Cell[BoxData["True"], "Output",
 CellID->1577727337]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<Pane\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}]}], "}"}]}], "]"}],
     ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
 CellID->1645078266],

Cell[BoxData["True"], "Output",
 CellID->418239739]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}], "}"}]}], "]"}], 
    ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
 CellID->50540228],

Cell[BoxData["True"], "Output",
 CellID->641316742]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<bar\>\"", ",", "\"\<foo\>\""}], "}"}], "}"}]}], "]"}], 
    ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
 CellID->1725226769],

Cell[BoxData["True"], "Output",
 CellID->390058501]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<bar\>\"", ",", "\"\<foo\>\""}], "}"}], "}"}]}], "]"}], 
    ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}], ",", 
    RowBox[{"FE`SearchDirection", "\[Rule]", "Backward"}]}], "]"}], 
  "]"}]], "Input",
 CellID->514625570],

Cell[BoxData["True"], "Output",
 CellID->1593135663]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}]}], "]"}], ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}], ",", 
    RowBox[{"FE`SearchDirection", "\[Rule]", "Backward"}], ",", 
    RowBox[{"FE`SearchStop", "\[Rule]", "\"\<StopAtEnd\>\""}], ",", 
    RowBox[{
    "FE`SearchStart", "\[Rule]", "\"\<StartFromCurrentSelection\>\""}]}], 
   "]"}], "]"}]], "Input",
 CellID->1352168717],

Cell[BoxData["False"], "Output",
 CellID->2146011795]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["BoxOffset Examples", "Subsubsubsection",
 CellID->749180460],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxChild", "[", "2", "]"}], "}"}]}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellID->1846530826],

Cell[BoxData["True"], "Output",
 CellID->812397787]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}], ",", 
      RowBox[{"FE`BoxOffset", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"FE`BoxParent", "[", "2", "]"}], "}"}]}]}], "]"}], ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}], ",", 
    RowBox[{"FE`SearchDirection", "\[Rule]", "Forward"}], ",", 
    RowBox[{
    "FE`SearchStart", "\[Rule]", "\"\<StartFromCurrentSelection\>\""}]}], 
   "]"}], "]"}]], "Input",
 CellID->2141853259],

Cell[BoxData["True"], "Output",
 CellID->268578483]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FE`BoxParent", "[", "1", "]"}], ",", 
        RowBox[{"FE`BoxChild", "[", "2", "]"}]}], "}"}]}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellID->1720176909],

Cell[BoxData["True"], "Output",
 CellID->285140367]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxAbsoluteSibling", "[", "2", "]"}], "}"}]}]}], "]"}], 
   "]"}], "]"}]], "Input",
 CellID->542317665],

Cell[BoxData["True"], "Output",
 CellID->1472368286]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxRightSibling", "[", "2", "]"}], "}"}]}]}], "]"}], "]"}],
   "]"}]], "Input",
 CellID->1035633800],

Cell[BoxData["True"], "Output",
 CellID->2100836783]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxRightSibling", "[", "3", "]"}], "}"}]}]}], "]"}], "]"}],
   "]"}]], "Input",
 CellID->1548818834],

Cell[BoxData["False"], "Output",
 CellID->1416802082]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxChild", "[", "1", "]"}], "}"}]}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellID->225350008],

Cell[BoxData["True"], "Output",
 CellID->1318131712]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Segments Examples", "Subsubsubsection",
 CellID->1118332392],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxChild", "[", "1", "]"}], "}"}]}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellID->1375015264],

Cell[BoxData["True"], "Output",
 CellID->348631744]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}], ",", 
     RowBox[{"FE`Segments", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}], "}"}]}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxChild", "[", "1", "]"}], "}"}]}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellID->221003654],

Cell[BoxData["True"], "Output",
 CellID->1865959683]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceFind", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellID->949439263],

Cell[BoxData["True"], "Output",
 CellID->1422196031]
}, Closed]],

Cell[BoxData["BoxAbsoluteSibling"], "Input",
 CellID->1849363420]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["BoxReferenceRead", "Subsection"],

Cell["\<\
The packet FrontEnd`BoxReferenceRead will return the entier box contents of \
the first box structure matching the given box reference. If no such box \
structure is found $Failed will be returned. The specified options control \
from what point we want to start searching from within the notebook, in which \
direction, and when we stop searching.\
\>", "ExampleText",
 CellID->652023650],

Cell["\<\
The box reference can optionally specify a chain of boxIDs which requires \
that there exist box parents of the box structure which have boxIDs which \
match the boxIDs in the box id chain. Additionally, the box reference can \
optionally contain an offset to parents, siblings, or children.\
\>", "ExampleText",
 CellID->1375267019],

Cell[BoxData[GridBox[{
   {
    RowBox[{"BoxReferenceRead", "[", 
     RowBox[{
      StyleBox["ref", "TI"], ",", 
      StyleBox["opts", "TI"]}], "]"}], Cell[TextData[{
     "This will attempt to read the nearest box structure in the notebook \
which matches the ",
     "box reference",
     " ",
     StyleBox["ref", "TI"],
     ". If a matching box structure is found return the box structure \
matched. Return ",
     StyleBox["$Failed", "MR"],
     " otherwise. "
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->1584915894],

Cell[CellGroupData[{

Cell["Possible options for the packet BoxReferenceRead are: ", "Notes",
 CellID->294273070],

Cell[BoxData[GridBox[{
   {" ", 
    RowBox[{"FE`SearchStart", "\[Rule]", 
     StyleBox["start", "TI"]}], Cell["\<\
Specifies from what place within the notebook we start the search for a box \
which matches the given box reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchStop", "\[Rule]", 
     StyleBox["stop", "TI"]}], Cell["\<\
Specifies how we will stop the search for the box which matches the given box \
reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchDirection", "\[Rule]", 
     StyleBox["dir", "TI"]}], Cell["\<\
Specifies in which direction we will the selection be just after the end of \
the present unit \
\>", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{
      GrayLevel[0.7]}}}},
 CellID->1293454384]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellID->673422843],

Cell[BoxData[
 RowBox[{
  RowBox[{"nb", "=", 
   RowBox[{"CreateDocument", " ", "@", " ", 
    RowBox[{"Cell", "[", 
     RowBox[{"CellGroupData", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cell", "[", 
          RowBox[{"\"\<Blah\>\"", ",", "\"\<Subtitle\>\""}], "]"}], ",", 
         RowBox[{"Cell", "[", 
          RowBox[{"\"\<floo\>\"", ",", "\"\<Text\>\""}], "]"}], ",", 
         RowBox[{"Cell", "[", 
          RowBox[{
           RowBox[{"BoxData", "[", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<f\>\"", ",", "\"\<[\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"SuperscriptBox", "[", 
                   RowBox[{"\"\<ab\>\"", ",", "\"\<2\>\"", ",", 
                    RowBox[{"BoxID", "\[RuleDelayed]", "\"\<foo\>\""}]}], 
                   "]"}], ",", "\"\<+\>\"", ",", "\"\<12\>\""}], "}"}], "]"}],
                ",", "\"\<]\>\""}], "}"}], "]"}], "]"}], ",", 
           "\"\<Input\>\""}], "]"}], ",", 
         RowBox[{"Cell", "[", 
          RowBox[{
           RowBox[{"BoxData", "[", 
            RowBox[{"PaneBox", "[", 
             RowBox[{
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"SuperscriptBox", "[", 
                  RowBox[{"\"\<xyz\>\"", ",", "\"\<q\>\"", ",", 
                   RowBox[{"BoxID", "\[RuleDelayed]", 
                    RowBox[{"{", 
                    RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}]}]}], 
                  "]"}], ",", "\"\<+\>\"", ",", "\"\<12\>\""}], "}"}], "]"}], 
              ",", 
              RowBox[{"BoxID", "\[RuleDelayed]", "\"\<Pane\>\""}]}], "]"}], 
            "]"}], ",", "\"\<Input\>\""}], "]"}], ",", 
         RowBox[{"Cell", "[", 
          RowBox[{
           RowBox[{"BoxData", "[", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<r\>\"", ",", "\"\<+\>\"", ",", "\"\<t\>\""}], 
              "}"}], "]"}], "]"}], ",", "\"\<Input\>\""}], "]"}]}], "}"}], 
       ",", "Closed"}], "]"}], "]"}]}]}], ";"}]], "Input",
 CellID->978902611],

Cell[CellGroupData[{

Cell["Multiple BoxID Examples", "Subsubsubsection",
 CellID->1367933390],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<Pane\>\"", ",", "\"\<foo\>\""}], "}"}]}], "]"}], ",", " ",
     
    RowBox[{"AutoScroll", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
 CellID->543963410],

Cell[BoxData[
 RowBox[{"SuperscriptBox", "[", 
  RowBox[{"\<\"xyz\"\>", ",", "\<\"q\"\>", ",", 
   RowBox[{"BoxID", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"\<\"foo\"\>", ",", "\<\"bar\"\>"}], "}"}]}]}], "]"}]], "Output",\

 CellID->426756820]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<Pane\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<bar\>\"", ",", "\"\<foo\>\""}], "}"}]}], "}"}]}], "]"}],
     ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
 CellID->1679792369],

Cell[BoxData[
 RowBox[{"SuperscriptBox", "[", 
  RowBox[{"\<\"xyz\"\>", ",", "\<\"q\"\>", ",", 
   RowBox[{"BoxID", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"\<\"foo\"\>", ",", "\<\"bar\"\>"}], "}"}]}]}], "]"}]], "Output",\

 CellID->381846924]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}]}], "]"}], ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
 CellID->1627855597],

Cell[BoxData[
 RowBox[{"SuperscriptBox", "[", 
  RowBox[{"\<\"xyz\"\>", ",", "\<\"q\"\>", ",", 
   RowBox[{"BoxID", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"\<\"foo\"\>", ",", "\<\"bar\"\>"}], "}"}]}]}], "]"}]], "Output",\

 CellID->285127255]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<bar\>\"", ",", "\"\<foo\>\""}], "}"}], "}"}]}], "]"}], 
    ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
 CellID->1386959625],

Cell[BoxData[
 RowBox[{"SuperscriptBox", "[", 
  RowBox[{"\<\"xyz\"\>", ",", "\<\"q\"\>", ",", 
   RowBox[{"BoxID", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"\<\"foo\"\>", ",", "\<\"bar\"\>"}], "}"}]}]}], "]"}]], "Output",\

 CellID->992207319]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<bar\>\"", ",", "\"\<foo\>\""}], "}"}], "}"}]}], "]"}], 
    ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}], ",", 
    RowBox[{"FE`SearchDirection", "\[Rule]", "Backward"}]}], "]"}], 
  "]"}]], "Input",
 CellID->679410778],

Cell[BoxData[
 RowBox[{"SuperscriptBox", "[", 
  RowBox[{"\<\"xyz\"\>", ",", "\<\"q\"\>", ",", 
   RowBox[{"BoxID", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"\<\"foo\"\>", ",", "\<\"bar\"\>"}], "}"}]}]}], "]"}]], "Output",\

 CellID->817891478]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"{", "\"\<foo\>\"", "}"}], "}"}]}], "]"}], ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}], ",", 
    RowBox[{"FE`SearchDirection", "\[Rule]", "Backward"}], ",", 
    RowBox[{"FE`SearchStop", "\[Rule]", "\"\<StopAtEnd\>\""}], ",", 
    RowBox[{
    "FE`SearchStart", "\[Rule]", "\"\<StartFromCurrentSelection\>\""}]}], 
   "]"}], "]"}]], "Input",
 CellID->2101844792],

Cell[BoxData["False"], "Output",
 CellID->259246299]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["BoxOffset Examples", "Subsubsubsection",
 CellID->2061398150],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxChild", "[", "2", "]"}], "}"}]}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellID->565029999],

Cell[BoxData["\<\"q\"\>"], "Output",
 CellID->1132924772]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}], "}"}], ",", 
      RowBox[{"FE`BoxOffset", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"FE`BoxParent", "[", "2", "]"}], "}"}]}]}], "]"}], ",", " ", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}], ",", 
    RowBox[{"FE`SearchDirection", "\[Rule]", "Forward"}], ",", 
    RowBox[{
    "FE`SearchStart", "\[Rule]", "\"\<StartFromCurrentSelection\>\""}]}], 
   "]"}], "]"}]], "Input",
 CellID->650677739],

Cell[BoxData[
 RowBox[{"PaneBox", "[", 
  RowBox[{
   RowBox[{"RowBox", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SuperscriptBox", "[", 
       RowBox[{"\<\"xyz\"\>", ",", "\<\"q\"\>", ",", 
        RowBox[{"BoxID", "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{"\<\"foo\"\>", ",", "\<\"bar\"\>"}], "}"}]}]}], "]"}], 
      ",", "\<\"+\"\>", ",", "\<\"12\"\>"}], "}"}], "]"}], ",", 
   RowBox[{"BoxID", "\[RuleDelayed]", "\<\"Pane\"\>"}]}], "]"}]], "Output",
 CellID->1476628702]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FE`BoxParent", "[", "1", "]"}], ",", 
        RowBox[{"FE`BoxChild", "[", "2", "]"}]}], "}"}]}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellID->1249956641],

Cell[BoxData["\<\"+\"\>"], "Output",
 CellID->1377569782]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxAbsoluteSibling", "[", "2", "]"}], "}"}]}]}], "]"}], 
   "]"}], "]"}]], "Input",
 CellID->1786710052],

Cell[BoxData["\<\"+\"\>"], "Output",
 CellID->794127767]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxRightSibling", "[", "2", "]"}], "}"}]}]}], "]"}], "]"}],
   "]"}]], "Input",
 CellID->629731412],

Cell[BoxData["\<\"12\"\>"], "Output",
 CellID->294513864]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxRightSibling", "[", "3", "]"}], "}"}]}]}], "]"}], "]"}],
   "]"}]], "Input",
 CellID->126170969],

Cell[BoxData["False"], "Output",
 CellID->2092189560]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxChild", "[", "1", "]"}], "}"}]}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellID->408322531],

Cell[BoxData["\<\"xyz\"\>"], "Output",
 CellID->532698942]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Segments Examples", "Subsubsubsection",
 CellID->1238581445],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}], "}"}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxChild", "[", "1", "]"}], "}"}]}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellID->1279355744],

Cell[BoxData["\<\"xyz\"\>"], "Output",
 CellID->211793851]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}], "}"}], ",", 
     RowBox[{"FE`Segments", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}], "}"}]}], ",", 
     RowBox[{"FE`BoxOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FE`BoxChild", "[", "1", "]"}], "}"}]}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellID->1748083528],

Cell[BoxData["$Failed"], "Output",
 CellID->1238850678]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceRead", "[", " ", 
   RowBox[{"FE`BoxReference", " ", "[", 
    RowBox[{"nb", ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}], "}"}]}], "]"}], 
   "]"}], "]"}]], "Input",
 CellID->1637719592],

Cell[BoxData[
 RowBox[{"SuperscriptBox", "[", 
  RowBox[{"\<\"xyz\"\>", ",", "\<\"q\"\>", ",", 
   RowBox[{"BoxID", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"\<\"foo\"\>", ",", "\<\"bar\"\>"}], "}"}]}]}], "]"}]], "Output",\

 CellID->1509387481]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", 
  RowBox[{"UndocumentedProtoTypeBuild", "[", "]"}], "]"}]], "Input",
 CellID->51071156],

Cell[BoxData["True"], "Output",
 CellID->1506943739]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["BoxReferenceReplace", "Subsection"],

Cell["\<\
FrontEnd`BoxReferenceReplace will replace the box structure referenced by the \
given box reference with the given replacement expression. If no such box \
structure is found $Failed will be returned. The specified options control \
from what point we want to start searching from within the notebook, in which \
direction, and when we stop searching.\
\>", "ExampleText"],

Cell["\<\
The box reference can optionally specify a chain of boxIDs which requires \
that there exist box parents of the box structure which have boxIDs which \
match the boxIDs in the box id chain. Additionally, the box reference can \
optionally contain an offset to parents, siblings, or children.\
\>", "ExampleText",
 CellID->746295672],

Cell[BoxData[GridBox[{
   {
    RowBox[{"BoxReferenceReplace", "[", 
     RowBox[{
      StyleBox["ref", "TI"], ",", 
      StyleBox["newBox", "TI"], ",", 
      StyleBox["opts", "TI"]}], "]"}], Cell[TextData[{
     "This will attempt to replace the nearest box structure in the notebook \
which matches the box reference ",
     StyleBox["ref", "TI"],
     " with the new boxe ",
     StyleBox["newBox", "TI"],
     ". If a matching box is found replace the matching box with ",
     StyleBox["newBox", "TI"],
     ". Return ",
     StyleBox["True", "MR"],
     " if the replacement occured or ",
     StyleBox["False", "MR"],
     " otherwise. "
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->809640906],

Cell[CellGroupData[{

Cell["Possible options for the packet BoxReferenceReplace are: ", "Notes",
 CellID->1178319750],

Cell[BoxData[GridBox[{
   {" ", 
    RowBox[{"FE`SearchStart", "\[Rule]", 
     StyleBox["start", "TI"]}], Cell["\<\
Specifies from what place within the notebook we start the search for a box \
which matches the given box reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchStop", "\[Rule]", 
     StyleBox["stop", "TI"]}], Cell["\<\
Specifies how we will stop the search for the box which matches the given box \
reference\
\>", "TableText"]},
   {" ", 
    RowBox[{"FE`SearchDirection", "\[Rule]", 
     StyleBox["dir", "TI"]}], Cell["\<\
Specifies in which direction we will the selection be just after the end of \
the present unit \
\>", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "2ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {None, None, None, None, {None}}, "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{
      GrayLevel[0.7]}}}},
 CellID->2073329263]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellID->1882763450],

Cell[BoxData[
 RowBox[{
  RowBox[{"nb", "=", 
   RowBox[{"CreateDocument", " ", "[", 
    RowBox[{
     RowBox[{"Cell", "[", 
      RowBox[{"CellGroupData", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cell", "[", 
           RowBox[{"\"\<Blah\>\"", ",", "\"\<Subtitle\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{"\"\<floo\>\"", ",", "\"\<Text\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{
            RowBox[{"BoxData", "[", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<f\>\"", ",", "\"\<[\>\"", ",", 
                RowBox[{"RowBox", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"SuperscriptBox", "[", 
                    RowBox[{"\"\<ab\>\"", ",", "\"\<2\>\"", ",", 
                    RowBox[{"BoxID", "\[RuleDelayed]", "\"\<foo\>\""}]}], 
                    "]"}], ",", "\"\<+\>\"", ",", "\"\<12\>\""}], "}"}], 
                 "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], "]"}], ",", 
            "\"\<Input\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{
            RowBox[{"BoxData", "[", 
             RowBox[{"PaneBox", "[", 
              RowBox[{
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"SuperscriptBox", "[", 
                   RowBox[{"\"\<xyz\>\"", ",", "\"\<q\>\"", ",", 
                    RowBox[{"BoxID", "\[RuleDelayed]", 
                    RowBox[{"{", 
                    RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}]}]}], 
                   "]"}], ",", "\"\<+\>\"", ",", "\"\<12\>\""}], "}"}], "]"}],
                ",", 
               RowBox[{"BoxID", "\[RuleDelayed]", "\"\<Pane\>\""}]}], "]"}], 
             "]"}], ",", "\"\<Input\>\""}], "]"}], ",", 
          RowBox[{"Cell", "[", 
           RowBox[{
            RowBox[{"BoxData", "[", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<r\>\"", ",", "\"\<+\>\"", ",", "\"\<t\>\""}], 
               "}"}], "]"}], "]"}], ",", "\"\<Input\>\""}], "]"}]}], "}"}], 
        ",", "Open"}], "]"}], "]"}], ",", 
     RowBox[{"WindowSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"410", ",", "718"}], "}"}]}], ",", 
     RowBox[{"WindowMargins", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "55"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"30", ",", "Automatic"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellID->433765605],

Cell[CellGroupData[{

Cell["Multiple BoxID Examples", "Subsubsubsection",
 CellID->2044044595],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceReplace", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<Pane\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\""}], "}"}]}], "}"}]}], "]"}],
     ",", 
    RowBox[{"SuperscriptBox", "[", 
     RowBox[{"\"\<bit\>\"", ",", "\"\<rod\>\"", ",", 
      RowBox[{"BoxID", "\[RuleDelayed]", 
       RowBox[{"{", 
        RowBox[{"\"\<foo\>\"", ",", "\"\<bar\>\"", ",", " ", "\"\<car\>\""}], 
        "}"}]}]}], "]"}]}], "]"}], "]"}]], "Input",
 CellID->1552949612],

Cell[BoxData["True"], "Output",
 CellID->1020114432]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MathLink`CallFrontEnd", "[", " ", 
  RowBox[{"FrontEnd`BoxReferenceReplace", "[", " ", 
   RowBox[{
    RowBox[{"FE`BoxReference", " ", "[", 
     RowBox[{"nb", ",", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<Pane\>\"", ",", "\"\<bar\>\""}], "}"}]}], "]"}], ",", 
    " ", "\"\<fuf\>\"", ",", 
    RowBox[{"AutoScroll", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
 CellID->1739025317],

Cell[BoxData["True"], "Output",
 CellID->754898367]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell["BoxReferenceSetOptions", "Subsection"],

Cell["BoxReferenceGetOptions", "Subsection",
 CellID->70722005]
}, Closed]]
},
PageWidth->WindowWidth,
WindowSize->{682, 351},
WindowMargins->{{Automatic, 346}, {Automatic, 46}},
ShowSelection->True,
TrackCellChangeTimes->False,
Magnification->1.,
FrontEndVersion->"6.1 for Mac OS X x86 (32-bit) (August 6, 2007)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Inherited Styles", "Subsection"], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]], 
      Cell[
       StyleData[
       StyleDefinitions -> 
        FrontEnd`FileName[{"Wolfram"}, "FormatPageStyles.nb", 
          CharacterEncoding -> "UTF-8"]]], 
      Cell[
       StyleData[
       StyleDefinitions -> 
        FrontEnd`FileName[{"Wolfram"}, "TutorialPageStyles.nb", 
          CharacterEncoding -> "UTF-8"]]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell["Overrides", "Subsection"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Notebook"], PageWidth -> WindowWidth, CreateCellID -> 
          True, TrackCellChangeTimes -> True, ShowStringCharacters -> True, 
          CacheGraphics -> False], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, 
          ShowCellBracket -> True, ShowAutoStyles -> False, ScriptMinSize -> 
          9, MenuPosition -> 1100]}, Open]], 
      Cell[
       StyleData["DefinitionBox"], CellMargins -> {{70, 12}, {8, 8}}, 
       MenuPosition -> 10000], 
      Cell[
       StyleData["Notes"], CellDingbat -> "\[FilledSmallSquare]", 
       CellMargins -> {{70, Inherited}, {Inherited, Inherited}}, 
       ReturnCreatesNewCell -> False, 
       CellGroupingRules -> {"SectionGrouping", 70}, DefaultNewCellStyle -> 
       "Text", LineSpacing -> {1, 2}, FontFamily -> "Verdana", FontSize -> 10,
        FontWeight -> "Plain", FontSlant -> "Plain"], 
      Cell[
       StyleData["2ColumnTableMod"], PageWidth -> WindowWidth, 
       CellMargins -> {{70, 50}, {6, 0}}, CellFrameColor -> 
       RGBColor[0.74902, 0.694118, 0.552941], SpanMaxSize -> 1, 
       StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 11, 
       ButtonBoxOptions -> {ButtonFrame -> "None"}, 
       GridBoxOptions -> {
        GridBoxAlignment -> {
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
         GridBoxItemSize -> {"Columns" -> {
             Scaled[0.05], 
             Scaled[0.41], {
              Scaled[0.565]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
           "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
             Offset[0.28], 
             Offset[0.14], {
              Offset[0.77]}, 
             Offset[0.28]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}}], 
      Cell[
       StyleData["TI"], StyleMenuListing -> None, FontFamily -> "Times", 
       FontSlant -> "Italic", Background -> RGBColor[0.118257, 1, 0.347021]], 
      
      Cell[
       StyleData["InputOnly"], PageWidth -> WindowWidth, ShowCellBracket -> 
       True, CellMargins -> {{75, 4}, {8, 8}}], 
      Cell[
       StyleData["ExampleText"], CellMargins -> {{70, 40}, {2, 8}}]}, Open]]},
   Visible -> False, FrontEndVersion -> 
  "6.1 for Mac OS X x86 (32-bit) (August 6, 2007)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 63, 1, 67, "Section",
 CellID->700496117],
Cell[633, 25, 62, 1, 27, "Input",
 CellID->82038956],
Cell[CellGroupData[{
Cell[720, 30, 54, 1, 34, "Subsection",
 CellID->732885565],
Cell[777, 33, 316, 6, 35, "ExampleText",
 CellID->1584626314],
Cell[1096, 41, 1949, 56, 185, "DefinitionBox",
 CellID->1894808774],
Cell[CellGroupData[{
Cell[3070, 101, 73, 1, 20, "Notes",
 CellID->828156497],
Cell[3146, 104, 1366, 37, 119, "2ColumnTableMod",
 CellID->984728872]
}, Closed]],
Cell[CellGroupData[{
Cell[4549, 146, 66, 1, 20, "Notes",
 CellID->1829167922],
Cell[4618, 149, 1896, 55, 159, "2ColumnTableMod",
 CellID->1596858249]
}, Closed]],
Cell[CellGroupData[{
Cell[6551, 209, 53, 1, 24, "Subsubsection",
 CellID->237833693],
Cell[6607, 212, 250, 8, 27, "Input",
 CellID->1892183385],
Cell[6860, 222, 255, 8, 27, "Input",
 CellID->1988306919],
Cell[7118, 232, 255, 8, 27, "Input",
 CellID->481356666],
Cell[7376, 242, 308, 9, 27, "Input",
 CellID->590587213],
Cell[7687, 253, 336, 10, 27, "Input",
 CellID->329872457],
Cell[8026, 265, 133, 4, 34, "Input",
 CellID->404509676],
Cell[8162, 271, 71, 1, 26, "Text",
 CellID->1808381777],
Cell[8236, 274, 330, 9, 27, "Input",
 CellID->136470048],
Cell[8569, 285, 524, 9, 61, "ExampleText",
 CellID->185165841],
Cell[9096, 296, 292, 8, 27, "Input",
 CellID->1016063255]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[9437, 310, 69, 1, 34, "Subsection",
 CellID->945442950],
Cell[9509, 313, 324, 6, 48, "ExampleText",
 CellID->1535105644],
Cell[CellGroupData[{
Cell[9858, 323, 81, 1, 20, "Notes",
 CellID->640650408],
Cell[9942, 326, 1053, 23, 98, "2ColumnTableMod",
 CellID->2075884845]
}, Closed]],
Cell[CellGroupData[{
Cell[11032, 354, 81, 1, 20, "Notes",
 CellID->2042728305],
Cell[11116, 357, 829, 20, 90, "2ColumnTableMod",
 CellID->313557546]
}, Closed]],
Cell[CellGroupData[{
Cell[11982, 382, 86, 1, 20, "Notes",
 CellID->1800650045],
Cell[12071, 385, 632, 14, 62, "2ColumnTableMod",
 CellID->1185752791]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[12764, 406, 46, 0, 37, "Section"],
Cell[CellGroupData[{
Cell[12835, 410, 31, 0, 34, "Subsection"],
Cell[12869, 412, 148, 3, 22, "ExampleText"],
Cell[13020, 417, 1142, 32, 163, "DefinitionBox",
 CellID->911805233],
Cell[14165, 451, 53, 1, 18, "Subsubsection",
 CellID->661661166],
Cell[CellGroupData[{
Cell[14243, 456, 54, 1, 18, "Subsubsection",
 CellID->1089009184],
Cell[14300, 459, 3221, 78, 163, "Input",
 CellID->2121715754],
Cell[CellGroupData[{
Cell[17546, 541, 71, 1, 24, "Subsubsubsection",
 CellID->710719043],
Cell[17620, 544, 573, 15, 79, "Input",
 CellID->868892796],
Cell[CellGroupData[{
Cell[18218, 563, 166, 4, 27, "Input",
 CellID->592422772],
Cell[18387, 569, 1679, 51, 69, "Output",
 CellID->686995272]
}, Closed]],
Cell[CellGroupData[{
Cell[20103, 625, 143, 3, 27, "Input",
 CellID->998971198],
Cell[20249, 630, 52, 1, 27, "Output",
 CellID->1457450232]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[20374, 639, 50, 1, 34, "Subsection",
 CellID->55799479],
Cell[20427, 642, 168, 4, 22, "ExampleText",
 CellID->101363491],
Cell[20598, 648, 834, 25, 98, "DefinitionBox",
 CellID->1518973461],
Cell[CellGroupData[{
Cell[21457, 677, 84, 1, 20, "Notes",
 CellID->122813910],
Cell[21544, 680, 1061, 29, 104, "2ColumnTableMod",
 CellID->401600603]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[22654, 715, 52, 1, 26, "Subsection",
 CellID->1686860824],
Cell[22709, 718, 150, 4, 22, "ExampleText",
 CellID->2138244921],
Cell[22862, 724, 298, 8, 63, "DefinitionBox",
 CellID->1491038349]
}, Closed]],
Cell[CellGroupData[{
Cell[23197, 737, 54, 1, 26, "Subsection",
 CellID->894854800],
Cell[23254, 740, 333, 6, 35, "ExampleText",
 CellID->996643659],
Cell[23590, 748, 444, 14, 63, "DefinitionBox",
 CellID->217530213],
Cell[CellGroupData[{
Cell[24059, 766, 88, 1, 20, "Notes",
 CellID->1910800934],
Cell[24150, 769, 1062, 29, 104, "2ColumnTableMod",
 CellID->1579348800]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[25273, 805, 74, 1, 37, "Section",
 CellID->1066281244],
Cell[CellGroupData[{
Cell[25372, 810, 61, 1, 34, "Subsection",
 CellID->1115341512],
Cell[25436, 813, 167, 4, 22, "ExampleText",
 CellID->1328217339],
Cell[25606, 819, 301, 9, 49, "DefinitionBox",
 CellID->2030364221],
Cell[CellGroupData[{
Cell[25932, 832, 91, 1, 20, "Notes",
 CellID->816311517],
Cell[26026, 835, 1062, 29, 104, "2ColumnTableMod",
 CellID->1622129183],
Cell[CellGroupData[{
Cell[27113, 868, 382, 10, 27, "Input",
 CellID->144232118],
Cell[27498, 880, 254, 7, 27, "Output",
 CellID->2130866529]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[27813, 894, 38, 0, 26, "Subsection"],
Cell[27854, 896, 446, 7, 48, "ExampleText"],
Cell[28303, 905, 343, 6, 35, "ExampleText",
 CellID->1869752951],
Cell[28649, 913, 581, 19, 78, "DefinitionBox",
 CellID->1721909340],
Cell[CellGroupData[{
Cell[29255, 936, 87, 1, 20, "Notes",
 CellID->32012],
Cell[29345, 939, 1315, 35, 136, "2ColumnTableMod",
 CellID->110873307]
}, Closed]],
Cell[CellGroupData[{
Cell[30697, 979, 54, 1, 18, "Subsubsection",
 CellID->1784821710],
Cell[30754, 982, 2635, 65, 133, "Input",
 CellID->1672851568],
Cell[CellGroupData[{
Cell[33414, 1051, 71, 1, 24, "Subsubsubsection",
 CellID->296387369],
Cell[CellGroupData[{
Cell[33510, 1056, 391, 10, 27, "Input",
 CellID->2068678937],
Cell[33904, 1068, 52, 1, 27, "Output",
 CellID->1577727337]
}, Closed]],
Cell[CellGroupData[{
Cell[33993, 1074, 460, 12, 43, "Input",
 CellID->1645078266],
Cell[34456, 1088, 51, 1, 27, "Output",
 CellID->418239739]
}, Closed]],
Cell[CellGroupData[{
Cell[34544, 1094, 417, 11, 27, "Input",
 CellID->50540228],
Cell[34964, 1107, 51, 1, 27, "Output",
 CellID->641316742]
}, Closed]],
Cell[CellGroupData[{
Cell[35052, 1113, 419, 11, 27, "Input",
 CellID->1725226769],
Cell[35474, 1126, 51, 1, 27, "Output",
 CellID->390058501]
}, Closed]],
Cell[CellGroupData[{
Cell[35562, 1132, 486, 13, 43, "Input",
 CellID->514625570],
Cell[36051, 1147, 52, 1, 27, "Output",
 CellID->1593135663]
}, Closed]],
Cell[CellGroupData[{
Cell[36140, 1153, 604, 14, 43, "Input",
 CellID->1352168717],
Cell[36747, 1169, 53, 1, 27, "Output",
 CellID->2146011795]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[36849, 1176, 66, 1, 18, "Subsubsubsection",
 CellID->749180460],
Cell[CellGroupData[{
Cell[36940, 1181, 425, 11, 43, "Input",
 CellID->1846530826],
Cell[37368, 1194, 51, 1, 27, "Output",
 CellID->812397787]
}, Closed]],
Cell[CellGroupData[{
Cell[37456, 1200, 661, 16, 58, "Input",
 CellID->2141853259],
Cell[38120, 1218, 51, 1, 27, "Output",
 CellID->268578483]
}, Closed]],
Cell[CellGroupData[{
Cell[38208, 1224, 499, 13, 58, "Input",
 CellID->1720176909],
Cell[38710, 1239, 51, 1, 27, "Output",
 CellID->285140367]
}, Closed]],
Cell[CellGroupData[{
Cell[38798, 1245, 435, 11, 43, "Input",
 CellID->542317665],
Cell[39236, 1258, 52, 1, 27, "Output",
 CellID->1472368286]
}, Closed]],
Cell[CellGroupData[{
Cell[39325, 1264, 432, 11, 43, "Input",
 CellID->1035633800],
Cell[39760, 1277, 52, 1, 27, "Output",
 CellID->2100836783]
}, Closed]],
Cell[CellGroupData[{
Cell[39849, 1283, 432, 11, 43, "Input",
 CellID->1548818834],
Cell[40284, 1296, 53, 1, 27, "Output",
 CellID->1416802082]
}, Closed]],
Cell[CellGroupData[{
Cell[40374, 1302, 424, 11, 43, "Input",
 CellID->225350008],
Cell[40801, 1315, 52, 1, 27, "Output",
 CellID->1318131712]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[40902, 1322, 66, 1, 18, "Subsubsubsection",
 CellID->1118332392],
Cell[CellGroupData[{
Cell[40993, 1327, 425, 11, 43, "Input",
 CellID->1375015264],
Cell[41421, 1340, 51, 1, 27, "Output",
 CellID->348631744]
}, Closed]],
Cell[CellGroupData[{
Cell[41509, 1346, 560, 15, 58, "Input",
 CellID->221003654],
Cell[42072, 1363, 52, 1, 27, "Output",
 CellID->1865959683]
}, Closed]],
Cell[CellGroupData[{
Cell[42161, 1369, 301, 8, 27, "Input",
 CellID->949439263],
Cell[42465, 1379, 52, 1, 27, "Output",
 CellID->1422196031]
}, Closed]],
Cell[42532, 1383, 65, 1, 27, "Input",
 CellID->1849363420]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[42658, 1391, 38, 0, 34, "Subsection"],
Cell[42699, 1393, 399, 7, 48, "ExampleText",
 CellID->652023650],
Cell[43101, 1402, 343, 6, 35, "ExampleText",
 CellID->1375267019],
Cell[43447, 1410, 536, 17, 78, "DefinitionBox",
 CellID->1584915894],
Cell[CellGroupData[{
Cell[44008, 1431, 91, 1, 20, "Notes",
 CellID->294273070],
Cell[44102, 1434, 1062, 29, 104, "2ColumnTableMod",
 CellID->1293454384]
}, Closed]],
Cell[CellGroupData[{
Cell[45201, 1468, 53, 1, 18, "Subsubsection",
 CellID->673422843],
Cell[45257, 1471, 2216, 53, 118, "Input",
 CellID->978902611],
Cell[CellGroupData[{
Cell[47498, 1528, 72, 1, 24, "Subsubsubsection",
 CellID->1367933390],
Cell[CellGroupData[{
Cell[47595, 1533, 390, 10, 27, "Input",
 CellID->543963410],
Cell[47988, 1545, 253, 7, 27, "Output",
 CellID->426756820]
}, Closed]],
Cell[CellGroupData[{
Cell[48278, 1557, 460, 12, 43, "Input",
 CellID->1679792369],
Cell[48741, 1571, 253, 7, 27, "Output",
 CellID->381846924]
}, Closed]],
Cell[CellGroupData[{
Cell[49031, 1583, 375, 9, 27, "Input",
 CellID->1627855597],
Cell[49409, 1594, 253, 7, 27, "Output",
 CellID->285127255]
}, Closed]],
Cell[CellGroupData[{
Cell[49699, 1606, 419, 11, 37, "Input",
 CellID->1386959625],
Cell[50121, 1619, 253, 7, 27, "Output",
 CellID->992207319]
}, Closed]],
Cell[CellGroupData[{
Cell[50411, 1631, 486, 13, 37, "Input",
 CellID->679410778],
Cell[50900, 1646, 253, 7, 27, "Output",
 CellID->817891478]
}, Closed]],
Cell[CellGroupData[{
Cell[51190, 1658, 604, 14, 37, "Input",
 CellID->2101844792],
Cell[51797, 1674, 52, 1, 27, "Output",
 CellID->259246299]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[51898, 1681, 67, 1, 24, "Subsubsubsection",
 CellID->2061398150],
Cell[CellGroupData[{
Cell[51990, 1686, 462, 12, 43, "Input",
 CellID->565029999],
Cell[52455, 1700, 57, 1, 27, "Output",
 CellID->1132924772]
}, Closed]],
Cell[CellGroupData[{
Cell[52549, 1706, 699, 17, 58, "Input",
 CellID->650677739],
Cell[53251, 1725, 504, 13, 27, "Output",
 CellID->1476628702]
}, Closed]],
Cell[CellGroupData[{
Cell[53792, 1743, 537, 14, 58, "Input",
 CellID->1249956641],
Cell[54332, 1759, 57, 1, 27, "Output",
 CellID->1377569782]
}, Closed]],
Cell[CellGroupData[{
Cell[54426, 1765, 474, 12, 58, "Input",
 CellID->1786710052],
Cell[54903, 1779, 56, 1, 27, "Output",
 CellID->794127767]
}, Closed]],
Cell[CellGroupData[{
Cell[54996, 1785, 469, 12, 43, "Input",
 CellID->629731412],
Cell[55468, 1799, 57, 1, 27, "Output",
 CellID->294513864]
}, Closed]],
Cell[CellGroupData[{
Cell[55562, 1805, 469, 12, 43, "Input",
 CellID->126170969],
Cell[56034, 1819, 53, 1, 27, "Output",
 CellID->2092189560]
}, Closed]],
Cell[CellGroupData[{
Cell[56124, 1825, 462, 12, 43, "Input",
 CellID->408322531],
Cell[56589, 1839, 58, 1, 27, "Output",
 CellID->532698942]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[56696, 1846, 66, 1, 18, "Subsubsubsection",
 CellID->1238581445],
Cell[CellGroupData[{
Cell[56787, 1851, 463, 12, 43, "Input",
 CellID->1279355744],
Cell[57253, 1865, 58, 1, 27, "Output",
 CellID->211793851]
}, Closed]],
Cell[CellGroupData[{
Cell[57348, 1871, 599, 16, 58, "Input",
 CellID->1748083528],
Cell[57950, 1889, 55, 1, 27, "Output",
 CellID->1238850678]
}, Closed]],
Cell[CellGroupData[{
Cell[58042, 1895, 341, 9, 27, "Input",
 CellID->1637719592],
Cell[58386, 1906, 254, 7, 27, "Output",
 CellID->1509387481]
}, Closed]],
Cell[CellGroupData[{
Cell[58677, 1918, 141, 3, 27, "Input",
 CellID->51071156],
Cell[58821, 1923, 52, 1, 27, "Output",
 CellID->1506943739]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[58946, 1932, 41, 0, 26, "Subsection"],
Cell[58990, 1934, 382, 6, 48, "ExampleText"],
Cell[59375, 1942, 342, 6, 35, "ExampleText",
 CellID->746295672],
Cell[59720, 1950, 713, 21, 78, "DefinitionBox",
 CellID->809640906],
Cell[CellGroupData[{
Cell[60458, 1975, 95, 1, 20, "Notes",
 CellID->1178319750],
Cell[60556, 1978, 1062, 29, 104, "2ColumnTableMod",
 CellID->2073329263]
}, Closed]],
Cell[CellGroupData[{
Cell[61655, 2012, 54, 1, 18, "Subsubsection",
 CellID->1882763450],
Cell[61712, 2015, 2634, 65, 133, "Input",
 CellID->433765605],
Cell[CellGroupData[{
Cell[64371, 2084, 72, 1, 24, "Subsubsubsection",
 CellID->2044044595],
Cell[CellGroupData[{
Cell[64468, 2089, 669, 17, 43, "Input",
 CellID->1552949612],
Cell[65140, 2108, 52, 1, 27, "Output",
 CellID->1020114432]
}, Closed]],
Cell[CellGroupData[{
Cell[65229, 2114, 414, 10, 43, "Input",
 CellID->1739025317],
Cell[65646, 2126, 51, 1, 27, "Output",
 CellID->754898367]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[65748, 2133, 44, 0, 26, "Subsection"],
Cell[65795, 2135, 63, 1, 26, "Subsection",
 CellID->70722005]
}, Closed]]
}
]
*)

(* End of internal cache information *)
